# Django PostgreSQL Signals

This django app allows you to pass events about database changes directly into Djagno as regular signal.


# Install

## Pypi

```
pip install pgsignals
```

## Github

```
pip install git+https://github.com/gtors/pgsignals#egg=pgsignals-0.1
```

# Usage


